@@ -8,10 +8,10 @@ It may be loaded with wildcard, eg:
 - from patlib.math import * # won't execute the other submodules
 """
 
-from importlib.metadata import version
-
 try:
-    __version__ = version(__name__)
-except:
-    pass
+    import importlib.metadata as importlib_metadata
+except ModuleNotFoundError:
+    import importlib_metadata  # type: ignore
 
+# https://github.com/python-poetry/poetry/pull/2366#issuecomment-652418094
+__version__ = importlib_metadata.version(__name__)
