@@ -1,7 +1,8 @@
+"""Provision matplotlib. Used via `from patlib.all import *`."""
 import matplotlib as mpl
 from matplotlib import pyplot as plt
 
-# Even though pylib is only meant for toying around,
+# Even though patlib is only meant for toying around,
 # I don't think I should do this just yet.
 # For example, for jupyter notebooks,
 # it might be desirable to not do it.
